@@ -7,6 +7,7 @@ pub trait PageNo: Ord + Hash + Copy + Unpin + Sync + Send + Default + Debug {
     const SIZE: usize;
     fn new(_: u32) -> Self;
     fn as_u32(self) -> u32;
+    fn as_u64(self) -> u64;
     fn to_bytes(&self) -> Vec<u8>;
     fn from_bytes(_: &[u8]) -> Self;
 }
@@ -17,7 +18,9 @@ macro_rules! impl_trait {
             #[inline]
             fn new(num: u32) -> Self { num.try_into().unwrap() }
             #[inline]
-            fn as_u32(self) -> u32 { self.try_into().unwrap() }
+            fn as_u32(self) -> u32 { self.into() }
+            #[inline]
+            fn as_u64(self) -> u64 { self.into() }
             #[inline]
             fn to_bytes(&self) -> Vec<u8> { self.to_le_bytes().to_vec() }
             #[inline]
@@ -55,4 +58,9 @@ impl PageNo for U24 {
     fn as_u32(self) -> u32 {
         self.0
     }
+
+    #[inline]
+    fn as_u64(self) -> u64 {
+        self.0.into()
+    }
 }
